@@ -6,7 +6,7 @@ use Business::OnlinePayment;
 use vars qw($VERSION @ISA $me);
 
 @ISA = qw(Business::OnlinePayment);
-$VERSION = '3.22';
+$VERSION = '3.23';
 $me = 'Business::OnlinePayment::AuthorizeNet';
 
 sub set_defaults {
@@ -67,12 +67,14 @@ Business::OnlinePayment::AuthorizeNet - AuthorizeNet backend for Business::Onlin
       amount         => '49.95',
       invoice_number => '100100',
       customer_id    => 'jsk',
+      email          => 'jason@example.com',
       first_name     => 'Jason',
       last_name      => 'Kohles',
       address        => '123 Anystreet',
       city           => 'Anywhere',
       state          => 'UT',
       zip            => '84058',
+      country        => 'US',
       card_number    => '4007000000027',
       expiration     => '09/02',
       cvv2           => '1234', #optional
@@ -102,12 +104,14 @@ Business::OnlinePayment::AuthorizeNet - AuthorizeNet backend for Business::Onlin
       amount         => '49.95',
       invoice_number => '100100',
       customer_id    => 'jsk',
+      email          => 'jason@example.com',
       first_name     => 'Jason',
       last_name      => 'Kohles',
       address        => '123 Anystreet',
       city           => 'Anywhere',
       state          => 'UT',
       zip            => '84058',
+      country        => 'US',
       card_number    => '4007000000027',
       expiration     => '09/02',
       cvv2           => '1234', #optional
@@ -361,7 +365,7 @@ from content(%content):
 
 Use your transaction key in the password field.
 
-Unlike Business::OnlinePayment or pre-3.0 verisons of
+Unlike Business::OnlinePayment or pre-3.0 versions of
 Business::OnlinePayment::AuthorizeNet, 3.1 requires separate first_name and
 last_name fields.
 
@@ -429,7 +433,7 @@ key" authentication as well support for the recurring_billing flag and the md5
 method that returns the MD5 hash which is returned by the gateway.
 
 Steve Simitzis contributed a patch for better compatibility with
-eProcessingNetwork's AuthorizeNet compatability mode.
+eProcessingNetwork's AuthorizeNet compatibility mode.
 
 Michael G. Schwern contributed cleanups, test fixes, and more.
 
@@ -446,6 +450,9 @@ Michael Peters fixed a bug in email address handling.
 Thomas Sibley <trs@bestpractical.com> wrote B:OP:AuthorizeNet::AIM::ErrorCodes
 which was borged and used to provide more descriptive error messages.
 
+Craig Pearlman <cpearlma@yahoo.com> sent in a patch to more accurately declare
+required fields for E-check transcations.
+
 =head1 CONTRIBUTIONS AND REPOSITORY
 
 Please send patches as unified diffs (diff -u) to (in order of preference):
@@ -466,16 +473,13 @@ Ivan Kohler <ivan-authorizenet@freeside.biz>
 
 =back
 
-The code is available from our public CVS repository:
+The code is available from our public git repository:
 
-  export CVSROOT=":pserver:anonymous@cvs.freeside.biz:/home/cvs/cvsroot"
-  cvs login
-  # The password for the user `anonymous' is `anonymous'.
-  cvs checkout Business-OnlinePayment-AuthorizeNet
+  git clone git://fit.freeside.biz/Business-OnlinePayment-AuthorizeNet.git
 
 Or on the web:
 
-  http://freeside.biz/cgi-bin/viewvc.cgi/Business-OnlinePayment-AuthorizeNet/
+  http://freeside.biz/gitweb/?p=Business-OnlinePayment-AuthorizeNet.git
 
 =head1 A WORD FROM OUR SPONSOR
 
@@ -486,7 +490,7 @@ visit http://freeside.biz/
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Freeside Internet Services, Inc.
+Copyright 2010-2015 Freeside Internet Services, Inc.
 Copyright 2008 Thomas Sibley
 All rights reserved.
 
